@@ -23,9 +23,9 @@ import java.util.Stack;
 import java.util.logging.Logger;
 
 import net.morilib.lisp.CompiledCode.Oper;
-import net.morilib.lisp.util.ArrayListStack;
 import net.morilib.lisp.util.LogEnv;
-import net.morilib.lisp.util.Stack2;
+import net.morilib.util.ArrayListStack;
+import net.morilib.util.Stack2;
 
 /*package*/ class CodeExecutorImpl implements CodeExecutor {
 	
